# GroupReconcileRecord

Information regarding the reconcile action take for a group

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the group | [optional] 
**org_id** | **str** | The unique id of the Organisation this group is associated with.   | [optional] 
**group_id** | **str** | The unique id of the group  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


